var Foo = function(_Bar__2) {
    _inherits(Foo__2, _Bar__2);
    function Foo__2() {}
    return Foo__2;
}(Bar);
